package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.MusicCollect;
import com.ruoyi.system.mapper.MusicCollectMapper;
import com.ruoyi.system.service.IMusicCollectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-18
 */
@Service
public class MusicCollectServiceImpl implements IMusicCollectService 
{
    @Autowired
    private MusicCollectMapper musicCollectMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public MusicCollect selectMusicCollectById(String id)
    {
        return musicCollectMapper.selectMusicCollectById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param musicCollect 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<MusicCollect> selectMusicCollectList(MusicCollect musicCollect)
    {
        return musicCollectMapper.selectMusicCollectList(musicCollect);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param musicCollect 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertMusicCollect(MusicCollect musicCollect)
    {
        return musicCollectMapper.insertMusicCollect(musicCollect);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param musicCollect 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateMusicCollect(MusicCollect musicCollect)
    {
        return musicCollectMapper.updateMusicCollect(musicCollect);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMusicCollectByIds(String[] ids)
    {
        return musicCollectMapper.deleteMusicCollectByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteMusicCollectById(String id)
    {
        return musicCollectMapper.deleteMusicCollectById(id);
    }
}
